# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from pyVmomi.sms.storage.replication import DeviceId

class VirtualDiskKey(DeviceId):
   vmInstanceUUID: str
   deviceKey: int
